
/* Chrysalide - Outil d'analyse de fichiers binaires
 * gtkviewpanel.h - prototypes pour l'affichage de contenu de binaire
 *
 * Copyright (C) 2010-2013 Cyrille Bagard
 *
 *  This file is part of Chrysalide.
 *
 *  OpenIDA is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  OpenIDA is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Foobar.  If not, see <http://www.gnu.org/licenses/>.
 */


#ifndef _GTK_VIEWPANEL_H
#define _GTK_VIEWPANEL_H


#include <glib-object.h>


#include "../analysis/binary.h"



#define GTK_TYPE_VIEW_PANEL                  (gtk_view_panel_get_type())
#define GTK_VIEW_PANEL(obj)                  (G_TYPE_CHECK_INSTANCE_CAST((obj), GTK_TYPE_VIEW_PANEL, GtkViewPanel))
#define GTK_VIEW_PANEL_CLASS(klass)          (G_TYPE_CHECK_CLASS_CAST((klass), GTK_TYPE_VIEW_PANEL, GtkViewPanelClass))
#define GTK_IS_VIEW_PANEL(obj)               (G_TYPE_CHECK_INSTANCE_TYPE((obj), GTK_TYPE_VIEW_PANEL))
#define GTK_IS_VIEW_PANEL_CLASS(klass)       (G_TYPE_CHECK_CLASS_TYPE((klass), GTK_TYPE_VIEW_PANEL))
#define GTK_VIEW_PANEL_GET_CLASS(obj)        (G_TYPE_INSTANCE_GET_CLASS((obj), GTK_TYPE_VIEW_PANEL, GtkViewPanelClass))


/* Composant d'affichage générique (instance) */
typedef struct _GtkViewPanel GtkViewPanel;

/* Composant d'affichage générique (classe) */
typedef struct _GtkViewPanelClass GtkViewPanelClass;


/* Détermine le type du composant d'affichage générique. */
GType gtk_view_panel_get_type(void);

/* Indique le type de contenu représenté par le composant. */
BinaryView gtk_view_panel_describe_content(const GtkViewPanel *);

/* Définit si une bordure est à afficher. */
void gtk_view_panel_show_border(GtkViewPanel *, bool);

/* Associe à un panneau d'affichage un binaire chargé. */
void gtk_view_panel_attach_binary(GtkViewPanel *, GLoadedBinary *, BinaryView);

/* Définit si les adresses doivent apparaître dans le rendu. */
void gtk_view_panel_set_addresses_display(GtkViewPanel *, bool);

/* Définit si le code doit apparaître dans le rendu. */
void gtk_view_panel_set_code_display(GtkViewPanel *, bool);

/* Fournit le binaire associé à la représentation. */
GLoadedBinary *gtk_view_panel_get_binary(const GtkViewPanel *);




/* Adaptation d'une position sur une surface */
typedef enum _ScrollPositionTweak
{
    SPT_RAW,                                /* Aucun ajustement            */
    SPT_TOP,                                /* Le plus haut possible       */
    SPT_CENTER,                             /* Au centre de la surface     */
    SPT_BOTTOM                              /* Le plus bas possible        */

} ScrollPositionTweak;

/* Indique la position courante du curseur. */
const vmpa2t *gtk_view_panel_get_caret_location(const GtkViewPanel *);

/* S'assure qu'une adresse donnée est visible à l'écran. */
void _gtk_view_panel_scroll_to_address(GtkViewPanel *, const vmpa2t *, ScrollPositionTweak, bool);

#define gtk_view_panel_scroll_to_address(p, a, t) _gtk_view_panel_scroll_to_address(p, a, t, true)



/* Demande à qui veut répondre un déplacement du curseur. */
void gtk_view_panel_request_move(GtkViewPanel *, const vmpa2t *);

/* Fournit des éléments liés à la position courante dans la vue. */
bool gtk_view_panel_get_position(const GtkViewPanel *, GBufferLine **, GBufferSegment **);

/* Place en cache un rendu destiné à l'aperçu graphique rapide. */
void gtk_view_panel_cache_glance(GtkViewPanel *, cairo_t *, const GtkAllocation *, double);



#endif  /* _GTK_VIEWPANEL_H */
